@@ -4,10 +4,11 @@
 # PARAMETERS
 import yaml
 import subprocess
+import os
 
 class Parameters:
     def __init__(self):
-        import os
+
 
         # Open yaml file and store the parameters
 
@@ -87,6 +88,8 @@ class Parameters:
                 var = raw_input(">>> ")
                 # If user doesn't enter anything, previous value it is
                 if (var!=""):
+                    if (var.isdigit()):
+                        var = int(var)
                     newdct[entry][sub] = var
 
         # rewrite the file
@@ -95,3 +98,12 @@ class Parameters:
 
         # Reload parameter file
         self.__init__()
+
+    def updateDatabase(self, dbFile,table,keywords):
+        script_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
+        rel_path = dbFile
+        self.sqlite = os.path.join(script_dir, rel_path)
+
+        self.table = table
+
+        self.usekeywords = keywords
