@@ -206,3 +206,6 @@ class PyJoke:
 
     def changeParams(self):
         self.params.change()
+
+    def changeDatabase(self, dbFile, table, keywords):
+        self.params.updateDatabase(dbFile, table, keywords)
